## UX strategy

**Context:**

Elsa is a seamstress. She makes swimsuits on demand through her instagram account. It's going well, her community is growing as well as the amount of requests from customers.

However, she loses a lot of time every time there is a request. To complete an order, she needs to ask for the shape of the swimsuit, the size, the color preferences and the expected delivery time. On top of that, she needs to make sure she has enough time to sew one piece. (every piece requires 6 hours)

For now, she only works with private messages but she wishes she could spend less time on that part.

You offer to help her design a solution to manage her time and workshop better. You have 4 working days.

### Instructions

Now you have discovered and practiced many tools in the design process, organize a time frame for the next 4 working days.

Select at least one tool for each phase, name it, and take into account the amount of time each phase may require.

- Empathy / User Research
- Define
- Problem Statement
- Ideation
- Prototype
- Test

### Deliverables

- A time frame, on PDF or on Figma, of the project, including:

  - The working days ahead.
  - Each phase of the process.
  - The main tools you plan to use for each phase.
  - The time you plan to spend for each tool.

Don't forget to:

- Upload the PDF or Figma document on Github, labeled as follows: “Name_FirstName_DeliverableName_Date_VersionNumber”. For example, it can be labeled as “Doe_John_MidFiPrototype_05242024_V1”.
- Add a title within the document.

**Tips:**

- Pay attention to the global aspect of the document. It must be clear, simple and easy to read. You can get inspiration [canva](https://www.canva.com/) but don’t overload your design with too much details!

**Resource:**

- [A sum up of all the tools that have been practiced](https://www.figma.com/file/x0xfoz9TaEDiAfGPFqKJcs/RECAP-UX%2FUI-Program?node-id=0%3A1). Focus on the UX part!

**Quotes:**

- Design needs to fail. Failure is even a necessary step, but ideally it should happen before a product is launched, during the prototype and test phases
- “UX Strategy lies at the intersection of UX and business. It provides a much better chance of creating successful products. It enables teams to see the “Big Picture” to achieve the business goals under uncertain conditions” Jamie Levy | UX Strategy: How to Devise Innovative Digital Products That People Want
- UX Strategy is the method by which you validate that your solution solves a problem for real customers in a dynamic marketplace because the market is constantly changing.

## Empathy

### Instructions

Run at least one of the Empathy tools in the design process.

### Deliverables

- A PDF document with the script of the tool context.
- Completed tool (scripts from user interviews, results from a quantitative analysis, etc.).
- A PDF document with the key learnings from this phase.

Don't forget to:

- Upload the documents on Github, in a zip folder named “ProjectTitle_Name_FirstName”, with all project deliverables as follows: “Name_FirstName_DeliverableName_Date_VersionNumber”. For example, the first deliverable can be named as “Doe_John_MidFiPrototype_05242024_V1”.
- Add a title within all written documents.

**Tips:**

- Use as many tools as needed, be make sure you do all the process in 4 working days!
- Pay attention to the global aspect of the deliverables. They must be clear, simple and easy to read. You can get inspiration [canva](https://www.canva.com/) but don’t overload your design with too much details!

**Criteria:**

- User interviews
  - The script is the interview guide. Make sure there is:
    - the main purpose of the interview
    - 1 to 3 hypotheses
    - a proper introduction that describes the interviewer and the purpose of this interview
    - 3 to 5 main topics
    - a few scan questions (demographics)
    - open-ended questions, max 10
    - a funnel process (>)
    - a conclusion with next steps and a thank you.
  - The completed tool is either:
    - 5 to 10 scripts from users
    - or an [Affinity Diagram](https://www.youtube.com/watch?v=VngWHIE4k9s) with the main elements
- Analytics
  - The script is the form. Make sure there is:
    - The main purpose of the form
    - 1 to 3 hypotheses
    - A proper introduction that describes the interviewer and the purpose of this interview
    - 3 to 5 main topics
    - A few scan questions (demographics)
    - Closed-ended, unbiased questions, max 10
    - A funnel process (>)
    - A conclusion with next steps and a thank you.
    - A broadcast strategy
  - The completed tool is a series of quantitative data from at least 100 answers.
- Competitive analysis
  - The script is the strategy. The student explains what they are looking for and how they plan to find it.
  - The completed tool is a report. Make sure there is;
    - There is an introduction
    - There is a [competitive landscape](https://venngage-wordpress.s3.amazonaws.com/uploads/2019/03/g2crowd-grid.png)
    - With 2 relevant axes
    - 10 organizations appear on the landscape
    - There is a [competitive table](https://venngage-wordpress.s3.amazonaws.com/uploads/2019/03/product-features-comparison-matrix.png)
    - With 5 to 10 criteria
    - 10 organizations appear on the table

## Define

### Instructions

Run at least one of the Define tools in the design process.

### Deliverables

- A PDF document with the script of the tool context.
- Completed tool (scripts from user interviews, results from a quantitative analysis, etc.).
- A PDF document with the key learnings from this phase.

Don't forget to:

- Upload the documents on Github, in a zip folder named “ProjectTitle_Name_FirstName”, with all project deliverables as follows: “Name_FirstName_DeliverableName_Date_VersionNumber”. For example, the first deliverable can be named as “Doe_John_MidFiPrototype_05242024_V1”.
- Add a title within all written documents.

**Tips:**

- Use as many tools as needed, be make sure you do all the process in 4 working days!
- Pay attention to the global aspect of the deliverables. They must be clear, simple and easy to read. You can get inspiration [canva](https://www.canva.com/) but don’t overload your design with too much details!

**Criteria:**

- Persona

  - The script is the list of insights the students uses to create the persona.
  - The completed tool is a [Persona board](https://miro.medium.com/max/1400/0*RbHfR6BHhhFIENNf). Make sure the key insights come from the field, from reality, but the persona itself is different from only one user.

- Empathy Map

  - The script is the list of insights the student uses to create the Empathy map.
  - The completed tool is an [Empathy Map](https://miro.medium.com/max/700/1*I1ffOWdPWQva3dCMQE-TAQ.png).

- User Journey

  - The script is the list of insights the student uses to create the User Journey.
  - The completed tool is a [User Journey Map](https://d2slcw3kip6qmk.cloudfront.net/marketing/blog/2017Q3/SEO-initiative-customer-journey-mapping/CustomerJourneyMap1.png).

- Jobs-to-be-done (JTBD)

  - The JTBD is tool that goes as a conclusion to another of the previous tools. Make sure:
    - The sentence is complete.
    - The "When" part involves a visit on the website.
    - The "I want to" part involves a practical action.
    - The "So I can" part involves a psychological or emotional purpose.

## Problem statement

### Instructions

Based on your research (Empathy & Define), define a problem statement to narrow the problem and KPIs to measure the success.

### Deliverables

- A PDF document with:

  - One problem statement.
  - 1 to 3 KPIs.
  - Key learnings from this phase.

Don't forget to:

- Upload the PDF document on Github, labeled as follows: “Name_FirstName_DeliverableName_Date_VersionNumber”. For example, it can be labeled as “Doe_John_MidFiPrototype_05242024_V1”.
- Add a title within the document.

**Tips:**

- KPIs: [check the SMART list](https://www.grow.com/blog/how-to-use-smart-goals-to-build-your-kpis))
- Pay attention to the global aspect of the document. It must be clear, simple and easy to read. You can get inspiration [canva](https://www.canva.com/) but don’t overload your design with too much details!

**Quote:**

Design is about solving problems. Fall in Love with the Problem, Not the Solution.

**Examples of Problem statements:**

- How might we help Pierre measure and prepare his hydration before a race?
  - Appropriate —> The problem statement is narrow enough to be specific for one painpoint, and broad enough to let creativity suggest many options. Also, it takes into accounts some of the key insights from the previous phases.
- How might we make sure Pierre doesn’t get dehydrated?
  - Too broad —> The problem statement is out of the scope of running, so the solutions cannot be integrated in the specific context of running.
- How might we make sure Pierre drinks the cups that are offered during the race?
  - Too narrow —> There are plenty of options to avoid dehydration without drinking the cups that are offered during the race.
- How might we provide Pierre with a drink that contains everything he needs to avoid dehydration?
  - Focused on the solution, not the problem —> The problem statement is supposed to rephrase the brief and take into account the insights from the previous phase.
- How might make sure Pierre doesn’t get drunk the night before the race?
  - Out of scope —> This is not about dehydration, nor about running.

## Ideation

### Instructions

Run at least one of the Ideation techniques in the design process.

### Deliverables

- A PDF document with the script of the tool context.
- Completed tool: a board with all the ideas - on paper or digitally on Miro or Figma.
- A PDF document with the key learnings from this phase.

Don't forget to:

- Upload the documents on Github, in a zip folder named “ProjectTitle_Name_FirstName”, with all project deliverables as follows: “Name_FirstName_DeliverableName_Date_VersionNumber”. For example, the first deliverable can be named as “Doe_John_MidFiPrototype_05242024_V1”.
- Add a title within all written documents.

**Tips:**

- Use as many tools as needed, and make sure you do all the process in 4 working days!
- Pay attention to the global aspect of the deliverables. They must be clear, simple and easy to read. You can get inspiration [canva](https://www.canva.com/) but don’t overload your design with too much details!

## Prototype

### Instructions

Make a prototype including the chosen solution.

### Deliverables

- Pictures of a paper prototype (low-fi with 6 to 12 different screens).
- An animated wireframe prototype on figma (mid-fi).
- A PDF file with the key learnings from this phase.

Don't forget to:

- Upload the documents on Github, in a zip folder named “ProjectTitle_Name_FirstName”, with all project deliverables as follows: “Name_FirstName_DeliverableName_Date_VersionNumber”. For example, the first deliverable can be named as “Doe_John_MidFiPrototype_05242024_V1”.
- Add a title within all written documents.

**Criteria:**

- User Flow
  Make sure that for each flow:

  - The user has a specific goal.
  - There is a starting point and and ending point, which is the goal of the user.
  - There is a series of actions organized in rectangles (actions) or diamond (choice).
  - The actions are linked with arrows.

- Card sorting
  Make sure that:
  - There is a script including the research goals.
  - The research goals are close to "rearrange the content".
  - There are pictures of the ongoing workshop.
  - There is a new content organization shown in a table with sticky notes (it can be a picture or digital).

**Tips:**

- Use as many tools as needed, and make sure you do all the process in 4 working days!
- You may use Card Sorting and User flows.
- Vocabulary:
  - Low-Fidelity: Paper Prototypes - [Example here](https://miro.medium.com/max/1400/1*5nUfqqA2gjdAYHagjbHA5w.jpeg)
  - Mid-Fidelity: Wireframes - black and white, only the main elements, on digital prototype tools - [Example here](https://miro.medium.com/max/1400/1*eGSfaxwYbxUFomYbyO6GWw.png)
  - High-Fidelity: Wireframes with color, styles, graphical details, and micro-interactions - [Example here](https://miro.medium.com/max/1400/1*Xn0HSKAvhr4TZzC9lN5udw.gif)
- Pay attention to the global aspect of the deliverables. They must be clear, simple and easy to read. You can get inspiration [canva](https://www.canva.com/) but don’t overload your design with too much details!

## Test protocol

### Instructions

Prepare a testing protocol and run it!

Recommended steps:

- Define the scope of the test.
- Recruit 5 users.
- Identify objectives: What are you proving?
- Establish metrics: How are you proving your design is efficient?
- Describe the steps and the instructions.
- Write an introduction to greet their user.
- Write a conclusion to thank the user.

### Deliverables

- A testing protocol script.
- Photos from the tests.
- A PDF file with the key learnings from the tests (5 tests are required) and from this phase.
- In the same PDF file you need to place at least 3 learnings or iteration suggestions to be made for the next version.

Don't forget to:

- Upload the documents on Github, in a zip folder named “ProjectTitle_Name_FirstName”, with all project deliverables as follows: “Name_FirstName_DeliverableName_Date_VersionNumber”. For example, the first deliverable can be named as “Doe_John_MidFiPrototype_05242024_V1”.
- Add a title within all written documents.

**Tips:**

- Pay attention to the global aspect of the deliverables. They must be clear, simple and easy to read. You can get inspiration [canva](https://www.canva.com/) but don’t overload your design with too much details!